function [WTP] = WTBcalculator(plr)
% WTPcalculator(plr)
% Gives a willingness to buy (in percent of maximum price willing to pay
% for perfect service)
%
% %plr = 0.9; %percentage
%
% R model/values based on E-model: http://www.itu.int/ITU-T/studygroups/com12/emodelv1/calcul.php
Rnot = 93.2; %Accounts for other environmental factors

BurstR = 1; %Explained in calculator (link)
Bpl = 6; %Explained in calculator (link)
Ieeff = 95 .* (plr./(plr./BurstR+Bpl)); %Ie is 0. Only Bpl will be varied
R = Rnot - Ieeff; %Array of R values for each package loss percent
%R = Rnot - (plr * 2.5); %R based on uncontrollable "always present"
%variables.
%%


MOS = zeros(1,length(R)); %Create empty array for MOS
for i = 1:length(R) % For different clauses of MOS, equation based on ITU G.107e
    if R(i) < 0
        MOS(i) = 1;
    elseif R(i) > 100
        MOS(i) = 4.5;
    else
        MOS(i) = 1 + (0.035) .* R(i) + (.000007) .* R(i) .* (R(i)-60) .* (100-R(i));
        if MOS(i) < 1
            MOS(i) = 1;
        end
    end
end
WTP = zeros(1,length(MOS));

for i = 1:length(MOS)
    WTP(i) = (MOS(i)-1)/(4.5-1)*1;
end

[WTP] = WTP;
%% If plotting:
% plr = plr./100; %Plotting plr in 0 to 1 scale
%figure();
%h = plot(plr,WTP,'LineWidth',2, 'Color','r');
%legend(h,'E-Model Formula', 'Location', 'NorthEast' );
%axis([0 1 0 1]);
%ylabel('Willingness to Pay');
%xlabel('Packet Loss Ratio');